@@ -5,6 +5,7 @@ from re import search
 from os import environ, execl
 
 from asyncio import (
+    gather,
     wait_for,
     new_event_loop,
     iscoroutinefunction,
@@ -31,8 +32,8 @@ from colorama import Fore, Style, init
 
 from .ws import Ws
 from .db import _DB
-from .obj import Message, Req, Community
-from .utils import Slots, clear
+from .obj import Message, Req, Community, _req, My
+from .utils import Slots, clear, one_or_list, to_list
 from .dataclass import Msg, Embed, Res
 from .exceptions import (
     AccountNotFoundInDotenv,
@@ -46,7 +47,7 @@ from .exceptions import (
 
 __all__ = ['Bot']
 with open(f'{Path(__file__).parent}/__init__.py') as f:
-    version = search(r'[0-9]+.[0-9]+.[0-9]+', f.read()).group()
+    version = search(r'p[0-9]+.[0-9]+.[0-9]+', f.read()).group()[1:]
 
 Coro_return_ws_msg = Callable[[], Coroutine[Msg, None, None]]
 Coro_return_Any    = Callable[[], Coroutine[Any, None, None]]
@@ -112,8 +113,8 @@ class Bot(Slots):
         self._db:   _DB                             = _DB()
         self._msg:  Message                         = Message()
         self._loop: AbstractEventLoop               = new_event_loop()
-        self.prefix = prefix
 
+        self.prefix       = prefix
         self.only_chats   = only_chats
         self.ignore_chats = ignore_chats
 
@@ -224,6 +225,7 @@ class Bot(Slots):
                     try_update()
                     clear()
                     print('Restarting...\n')
+                    Path('db.db').unlink(missing_ok=True)
                     execl(sys.executable, Path(__file__).absolute(), *sys.argv)
                 clear()
 
@@ -233,7 +235,7 @@ class Bot(Slots):
         """
 
         self._loop.run_until_complete(self.check_update())
-        self._ws: Ws = Ws(
+        self._ws = Ws(
             loop         = self._loop,
             email        = self._email,
             password     = self._password,
@@ -258,6 +260,33 @@ class Bot(Slots):
         except:
             raise fut.exception()
 
+    async def status(
+        self,
+        s:           Literal['on', 'off'],
+        com:         str | list[str] | None = None
+    ) -> Res | list[Res]:
+        """
+        Changes the status of the bot
+
+        'on' the bot goes online
+
+        'off' the bot goes offline
+
+        By default, the bot changes the status in all communities where it is
+
+        However you can insert the communities so it stays online or offline
+        """
+
+        assert s in ['on', 'off'], f"Choose 'on' or 'off', not {s}"
+
+        async def foo(i):
+            return await _req('post', f'x{i}/s/user-profile/{self.id}/online-status', data)
+
+        data = {'onlineStatus': 1} if s == 'on' else {'onlineStatus': 2, 'duration': 86400} # 1 day
+        com = to_list(com or [i for i in (await My.communities(False)).values()])
+
+        return one_or_list(await gather(*[foo(i) for i in com]))
+
     async def send(
         self,
         *msgs: list[str],
@@ -289,7 +318,7 @@ class Bot(Slots):
     async def wait_for(
         self,
         check:   Callable[[Msg], bool] = lambda _: True,
-        timeout: int | None              = None
+        timeout: int | None            = None
     ) -> Awaitable[Future, int | None] | None:
         """
         Wait for a message until the check is met or timeout finish
