@@ -8,4 +8,7 @@ class InvalidEvent(Exception): pass
 class InvalidFileType(Exception): pass
 class InvalidReturn(Exception): pass
 class AminoSays(Exception): pass
-class EmptyCom(Exception): pass
\ No newline at end of file
+class EmptyCom(Exception): pass
+class InvalidRole(Exception): pass
+class InvalidPythonVersion(Exception): pass
+class FontNotFound(Exception): pass
\ No newline at end of file
